@@ -6,15 +6,28 @@ use Errno ();
 use File::Basename qw(basename);
 use Getopt::Long qw(:config no_auto_abbrev no_ignore_case bundling);
 use IO::Handle;
-use IO::Prompt 'prompt';
 use IO::Pty;
 use IO::Select;
-use List::MoreUtils qw(uniq);
+use List::Util qw(uniq);
 use Net::OpenSSH;
 use POSIX qw(strftime);
 use Parallel::ForkManager 1.16;
 use Pod::Usage 'pod2usage';
 use String::Glob::Permute qw(string_glob_permute);
+use Term::ReadKey 'ReadMode';
+
+sub prompt {
+    my $msg = shift;
+    chomp $msg;
+    STDOUT->printflush($msg);
+    local $SIG{INT} = sub { ReadMode 'restore', \*STDIN; STDOUT->printflush("\n"); exit };
+    ReadMode 'noecho', \*STDIN;
+    my $answer = <STDIN>;
+    ReadMode 'restore', \*STDIN;
+    STDOUT->printflush("\n");
+    chomp $answer;
+    $answer;
+}
 
 use constant CHUNK_SIZE => 1024 * 1024;
 
@@ -22,7 +35,7 @@ my $SUDO_PROMPT = sprintf "sudo password (asking with %s): ", basename($0);
 
 STDOUT->autoflush(1);
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub new {
     my $class = shift;
@@ -272,7 +285,7 @@ sub parse_options {
     );
 
     if ($ask_sudo_password) {
-        my $password = prompt $SUDO_PROMPT, -echo => undef;
+        my $password = prompt $SUDO_PROMPT;
         $self->{sudo_password} = $password;
     }
     $self->{host} = $host_file ? $self->parse_host_file($host_file)
@@ -325,7 +338,7 @@ please use C<ssh-agent>.
 
 =head1 LICENSE
 
-Copyright 2015 Shoichi Kaji <skaji@cpan.org>
+Copyright 2016 Shoichi Kaji <skaji@cpan.org>
 
 This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
